import React from "react"
import { graphql, PageProps } from "gatsby"
import dayjs from "dayjs"
import { twMerge } from "tailwind-merge"

import { ArrowCircleLeftIcon } from "@heroicons/react/outline"
import {
    Badge,
    Card,
    Image,
    Button,
    Layout,
    Content,
    Link,
    SideBar,
} from "@onegeo-suite/gatsby-theme-onegeo"

interface Idata {
    directus: {
        news: {
            id: string
            title: string
            date_published: string
            author: string
            image: {
                id: string
                imageFile: {
                    publicURL: string
                }
            }
            links: {
                id: string
                links_id: {
                    url: string
                }
            }
            documents: {
                directus_files_id: {
                    filename_disk: string
                    imageFile: {
                        publicURL: string
                    }
                    id: number
                }
            }
            categories: {
                name: string
            }
            content: string
            link: string
        }
    }
}

// http://localhost:8000/news/avancement-bd-ortho-2021 (avec doc)
// http://localhost:8000/news/mise-a-disposition-des-ortho-images-de-2015-sur-la-cacl (sans doc)

const News = ({ pageContext, data, location }: PageProps<Idata>) => {
    const news = data.directus.news[0]

    const urlImage = data.directus.news[0].image?.imageFile?.publicURL
    const categoryName = data.directus.news[0].categories?.name

    const { content, title, author, links, documents, date_published } = news

    const dataPub = dayjs(date_published).format("DD/MM/YYYY")

    let position = "right"

    return (
        <Layout>
            <Content className="max-w-6xl lg:mt-8">
                <div className="bg-base-100 rounded-xl p-6 lg:shadow-lg">
                    <Button
                        aria-label="Retour"
                        className="btn-ghost text-primary gap-2 font-bold normal-case"
                        url="/news"
                    >
                        <ArrowCircleLeftIcon
                            className="mr-2 h-6 w-6"
                            aria-hidden="true"
                        />
                        Toutes les actualités
                    </Button>

                    <p className="text-xl font-bold sm:text-2xl md:text-3xl">
                        {title}
                    </p>
                    <p className="text-primary mt-2 text-sm font-semibold tracking-wide">
                        Soumis par {author} le {dataPub}
                    </p>
                    <Badge title={categoryName} className="badge-lg mt-2" />
                </div>

                <div className="mb-8 mt-8 flex flex-wrap gap-6 lg:flex-nowrap">
                    {/* Todo Fix mobile mode */}
                    {position === "left" ? (
                        <SideBar documents={documents} links={links} />
                    ) : null}

                    <div className="bg-base-100 w-full rounded-xl p-6 lg:shadow-lg">
                        <div
                            className="prose max-w-4xl"
                            dangerouslySetInnerHTML={{
                                __html: content,
                            }}
                        ></div>
                    </div>

                    {position === "right" ? (
                        <SideBar documents={documents} links={links} />
                    ) : null}
                </div>
                <div className="mb-24 flex justify-center">
                    <div className="flex w-5/6 space-x-4">
                        <Card
                            url={"/news/" + pageContext.prev?.slug}
                            name="Précédent"
                            description={pageContext.prev?.title}
                            layout="left"
                            size="xs"
                            image={
                                pageContext.prev?.image != null
                                    ? pageContext.prev?.image?.imageFile
                                          ?.publicURL
                                    : "mock"
                            }
                        />
                        {pageContext.next ? (
                            <Card
                                url={"/news/" + pageContext.next?.slug}
                                name="Suivant"
                                description={pageContext.next?.title}
                                layout="left"
                                size="xs"
                                image={
                                    pageContext.next?.image != null
                                        ? pageContext.next?.image?.imageFile
                                              ?.publicURL
                                        : "mock"
                                }
                            />
                        ) : null}
                    </div>
                </div>
            </Content>
        </Layout>
    )
}

export default News

export const query = graphql`
    query ($id: DirectusData_GraphQLStringOrFloat!) {
        directus {
            news(filter: { id: { _eq: $id } }) {
                id
                title
                content
                date_published
                author
                image {
                    id
                    imageFile {
                        publicURL
                    }
                }
                links {
                    id
                    links_id {
                        url
                    }
                }
                documents {
                    directus_files_id {
                        id
                        filename_download
                        imageFile {
                            publicURL
                        }
                    }
                }
                categories {
                    name
                }
            }
        }
    }
`
